==> GeneSpring_1.0.1.tar.gz: GeneSpring/man/GSint.Rd <==
\name{GSint}
\alias{GSint}
\title{ Creation of GSint class object }
\description{
The \code{GSint} class object contains the expression values and the annotations
of the GeneSpring Expriment Interpretation object. Apart from the \code{new} function,
the function \code{GSint} can be used to create a new \code{GSint} object.
}

\usage{
new("GSint",
        expName       = ....  # Object of class "character",
        a.nor         = ....  # Object of class "matrix",
        se.nor        = ....  # Object of class "matrix",
        sd.nor        = ....  # Object of class "matrix",
        n.nor         = ....  # Object of class "matrix",
        a.raw         = ....  # Object of class "matrix",
        se.raw        = ....  # Object of class "matrix",
        sd.raw        = ....  # Object of class "matrix",
        n.raw         = ....  # Object of class "matrix",
        a.ctr         = ....  # Object of class "matrix",
        se.ctr        = ....  # Object of class "matrix",
        sd.ctr        = ....  # Object of class "matrix",
        n.ctr         = ....  # Object of class "matrix",
        expparam      = ....  # Object of class "data.frame",
        numConditions = ....  # Object of class "numeric",
        ngenes        = ....  # Object of class "numeric"
)

GSint(expName = "GeneSpring experiment",
        a.nor = matrix(nc = 0, nr = 0),
        se.nor = matrix(nc = 0, nr = 0),
        sd.nor = matrix(nc = 0, nr = 0),
        n.nor = matrix(nc = 0, nr = 0),
        a.raw = matrix(nc = 0, nr = 0), 
        se.raw = matrix(nc = 0, nr = 0), 
        sd.raw = matrix(nc = 0, nr = 0), 
        n.raw = matrix(nc = 0, nr = 0),
        a.ctr = matrix(nc = 0, nr = 0),
        se.ctr = matrix(nc = 0, nr = 0),
        sd.ctr = matrix(nc = 0, nr = 0),
        n.ctr = matrix(nc = 0, nr = 0),
        expparam = data.frame(),
        numConditions = 0,
        ngenes = 0
)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{expName}{Experiment name}
\item{a.nor}{Matrix representing the AVERAGE expression values for the NORMALIZED expression values}
\item{se.nor}{Matrix representing the STANDARD ERROR for the NORMALIZED expression values}
\item{sd.nor}{Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values}
\item{n.nor}{Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values}
\item{a.raw}{Matrix representing the AVERAGE expression values for the RAW expression values}
\item{se.raw}{Matrix representing the STANDARD ERROR for the RAW expression values}
\item{sd.raw}{Matrix representing the STANDARD DEVIATION for the RAW expression values}
\item{n.raw}{Matrix representing the NUMBER OF REPLICATES in this condition for the RAW values}
\item{a.ctr}{Matrix representing the AVERAGE expression values for the CONTROL values}
\item{se.ctr}{Matrix representing the STANDARD ERROR for the CONTROL values}
\item{sd.ctr}{Matrix representing the STANDARD DEVIATION for the CONTROL values}
\item{n.ctr}{Matrix representing the NUMBER OF REPLICATES in this condition for the CONTROL values}
\item{expparam}{Data drame representin the sample attributes or experimental parameters}
\item{numConditions}{Numeric value representing the number of conditions (or samples) in this interpretaion or experiment}
\item{ngenes}{Numeric values representing the number of genes in the experiment}
}
\details{
The \code{GSint} class object is a representation of a GeneSpring Experiment Interpretation.
The object consists of 16 slots:

1) The name of the experiment (slot: expName)
2) Twelve slots representing the various types of expression data as matrix objects
3) The experimental parameters (slot: expparam)
4) The number of samples or conditions in the experiment (slot: numConditions)
5) The number of genes (slot: ngenes)

All of the expression value slots are optional and are not guaranteed to contain data.
When a GeneSpring Experiment is read in from file, only the a.nor slot and optionally
the a.ctr slot will contain data.
When a GeneSpring Experiment INTERPRETATION is read, any of the 12 expression values slots
could contain data. Which data slots are filled is dependent on which choices were made
in the construction of the external programs in GeneSpring.

For more information about GeneSpring external programs see the GeneSpring manual.
For more information about the differences between an Experiment and an Interpretation
see the R manual entries for \code{\link{GSload.int}} and \code{\link{GSload.exp}}.
}

\value{
Both \code{GSint} and \code{new} return an object of class \code{GSint}.
}
\references{ 

For more information on using GeneSpring with R see
\url{http://www.silicongenetics.com/cgi/SiG.cgi/Support/GeneSpring/GSnotes/R.smf}
}

\author{ 
   Thon de Boer, Silicon Genetics, Redwood city, CA, USA \email{thon@silicongenetics.com}

}

\note{ This and any other functions in the GeneSpring package are only useful,
when using Silicon Genetics Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.int}},
\code{\link{GSload.exp}},
\code{\link{GSsave.exp}},
\code{\link{GSint2BC}},
\code{\link{BC2GSint}}
}

\examples{
#Create some simple sample annotation
ep <- t(data.frame(SampleName=1:10))
#Create a GSint object with random data as the RAW data object
gs.int <- GSint(expName="Random data",a.raw=matrix(rnorm(1000),nc=10),expparam=ep)

gs.int@expName
t(gs.int@expparam)
}

\keyword{ IO }% at least one, from doc/KEYWORDS

==> GeneSpring_2.4.0.tar.gz: GeneSpring/man/GSint.Rd <==
\name{GSint}
\alias{GSint-class}
\alias{show,GSint-method}
\alias{GSint}
\title{ Creation of GSint class object }
\description{
The \code{GSint} class object contains the expression values and the annotations
of the GeneSpring Expriment Interpretation object. Apart from the \code{new} function,
the function \code{GSint} can be used to create a new \code{GSint} object.
}

\usage{
GSint(expName = "GeneSpring experiment",
        a.nor = matrix(nc = 0, nr = 0),
        se.nor = matrix(nc = 0, nr = 0),
        sd.nor = matrix(nc = 0, nr = 0),
        n.nor = matrix(nc = 0, nr = 0),
        a.raw = matrix(nc = 0, nr = 0), 
        se.raw = matrix(nc = 0, nr = 0), 
        sd.raw = matrix(nc = 0, nr = 0), 
        n.raw = matrix(nc = 0, nr = 0),
        a.ctr = matrix(nc = 0, nr = 0),
        se.ctr = matrix(nc = 0, nr = 0),
        sd.ctr = matrix(nc = 0, nr = 0),
        n.ctr = matrix(nc = 0, nr = 0),
        expparam = data.frame(),
        numConditions = 0,
        ngenes = 0,
        genenames = c("")
)
}

%- maybe also 'usage' for other objects documented here.
\arguments{
\item{expName}{Experiment name}
\item{a.nor}{Matrix representing the AVERAGE expression values for the NORMALIZED expression values}
\item{se.nor}{Matrix representing the STANDARD ERROR for the NORMALIZED expression values}
\item{sd.nor}{Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values}
\item{n.nor}{Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values}
\item{a.raw}{Matrix representing the AVERAGE expression values for the RAW expression values}
\item{se.raw}{Matrix representing the STANDARD ERROR for the RAW expression values}
\item{sd.raw}{Matrix representing the STANDARD DEVIATION for the RAW expression values}
\item{n.raw}{Matrix representing the NUMBER OF REPLICATES in this condition for the RAW values}
\item{a.ctr}{Matrix representing the AVERAGE expression values for the CONTROL values}
\item{se.ctr}{Matrix representing the STANDARD ERROR for the CONTROL values}
\item{sd.ctr}{Matrix representing the STANDARD DEVIATION for the CONTROL values}
\item{n.ctr}{Matrix representing the NUMBER OF REPLICATES in this condition for the CONTROL values}
\item{expparam}{Data drame representin the sample attributes or experimental parameters}
\item{numConditions}{Numeric value representing the number of conditions (or samples) in this interpretaion or experiment}
\item{ngenes}{Numeric values representing the number of genes in the experiment}
\item{genenames}{List representing the gene names in the experiment}
}

\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "GSint")}: Produces a short description of the GSint class. It lists all the objects contained in the class. }
  }
}


\details{
The \code{GSint} class object is a representation of a GeneSpring Experiment Interpretation.
The object consists of 17 slots:

1) The name of the experiment (slot: expName)
2) Twelve slots representing the various types of expression data as matrix objects
3) The experimental parameters (slot: expparam)
4) The number of samples or conditions in the experiment (slot: numConditions)
5) The number of genes (slot: ngenes)
5) A list of the gene names(slot: genenames)

All of the expression value slots are optional and are not guaranteed to contain data.
When a GeneSpring Experiment is read in from file, only the a.nor slot and optionally
the a.ctr slot will contain data.
When a GeneSpring Experiment INTERPRETATION is read, any of the 12 expression values slots
could contain data. Which data slots are filled is dependent on which choices were made
in the construction of the external programs in GeneSpring.

For more information about GeneSpring external programs see the GeneSpring manual.
For more information about the differences between an Experiment and an Interpretation
see the R manual entries for \code{\link{GSload.int}} and \code{\link{GSload.exp}}.
}

\value{
Both \code{GSint} and \code{new} return an object of class \code{GSint}.
}
\references{ 

For more information on using GeneSpring with R see
\url{http://www.chem.agilent.com/scripts/generic.asp?lpage=34733}
}

\author{ 
   Thon de Boer, Agilent Technologies, Santa Clara, CA, USA \email{thon\_deboer@agilent.com}
}

\note{ This and any other functions in the GeneSpring package are only useful,
when using Agilent Technologies Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.int}},
\code{\link{GSload.exp}},
\code{\link{GSsave.exp}},
\code{\link{GSint2BC}},
\code{\link{BC2GSint}}
}

\examples{
#Create some simple sample annotation
ep <- t(data.frame(SampleName=1:10))
#Create a GSint object with random data as the RAW data object
gs.int <- GSint(expName="Random data",a.raw=matrix(rnorm(1000),nc=10),expparam=ep, genenames=1:100)

gs.int@expName
t(gs.int@expparam)
}

\keyword{ classes }% at least one, from doc/KEYWORDS
